Documentation:
https://brianp8701.github.io/swarmstar/

Building web app interface to use swarmstar:
https://github.com/BrianP8701/swarmstar_interface

This project is not ready to be used or reliable yet. I'll continue to update this as I make progress.

[AI Agent Swarm Playlist](https://youtube.com/playlist?list=PLO8gVow6df_Rh7DEJ10_WAdnkGnIRCh-K&si=eYdyBu7NShKckilS)
